@@ -1,12 +1,24 @@
 import json
 import boto3
+from shutil import copyfile
+
+
 import cloudpickle
 from botocore.exceptions import ClientError
 from mlops_sdk.config import Config
 from mlops_sdk.mlops_client import MlopsError
-from mlops_sdk.models.ml_model import MLModel
+from mlops_sdk.models.mlops_model import MLOpsModel
 
 from pathlib import Path
+import hvac
+
+
+def get_secrets(mount_point, path, parse_data=True):
+    vault_client = hvac.Client()
+    data = vault_client.secrets.kv.v2.read_secret_version(mount_point=mount_point, path=path)
+    if parse_data:
+        data = data["data"]["data"]
+    return data
 
 
 class ModelRegistryError(Exception):
@@ -35,7 +47,7 @@ class ModelRegistry:
         ```
         """
 
-    def save(self, ml_model: "MLModel", force: bool = False, model_path: str = None) -> None:
+    def save(self, ml_model: MLOpsModel, force: bool = False, model_artifact: str = None) -> None:
         """
         모델 바이너리(model.joblib)와 정보(model.json)를 모델 레지스트리에 등록합니다.
 
@@ -49,7 +61,7 @@ class ModelRegistry:
         model_registry.save(gbm_model)
         ```
         """
-        relative_path = Path("myfiles", "models") if self.config.RUNTIME_ENV == "EDD" else Path("models")
+        relative_path = Path("models")
         relative_path = relative_path.joinpath(ml_model.name, ml_model.version)
 
         path = Path.home().joinpath(relative_path)
@@ -57,6 +69,9 @@ class ModelRegistry:
         with open(path.joinpath("model.joblib"), "wb") as f:
             cloudpickle.dump(ml_model, f)
 
+        if model_artifact:
+            copyfile(model_artifact, str(path.joinpath("model.tar.gz")))
+
         with path.joinpath("model.json").open("w") as f:
             json.dump(
                 {
@@ -70,7 +85,16 @@ class ModelRegistry:
 
         if self.config.RUNTIME_ENV == "LOCAL":
             client = boto3.client("s3")
-            bucket_name = f"mlops-model-registry-{self.config.ENV.lower()}"
+            bucket_name = None
+            s3_info = get_secrets(mount_point="datafabric", path="mlops/access/data_loader")
+
+            if self.config.ENV == "DEV":
+                bucket_name = s3_info["model_registry_dev"]
+            elif self.config.ENV == "STG":
+                bucket_name = s3_info["model_registry_stg"]
+            else:
+                raise MlopsError(code=400, msg=f"ENV {self.config.ENV} does not exist.")
+
             try:
                 client.head_bucket(Bucket=bucket_name)
             except ClientError:
@@ -84,7 +108,7 @@ class ModelRegistry:
                     if "Contents" in response:
                         raise MlopsError(code=400, msg=f"Model binary & meta files already exist on {model_path}.")
 
-            for file_name in ["model.joblib", "model.json"]:
+            for file_name in ["model.joblib", "model.json", "model.tar.gz"]:
                 try:
                     client.upload_file(
                         Filename=f"{str(path)}/{file_name}", Bucket=bucket_name, Key=f"{model_path}/{file_name}"
